@@ -7,7 +7,7 @@ use Getopt::Long;# 2.33;
 use urpm::download;
 use urpm::msg;
 
-(our $VERSION) = q$Id: args.pm,v 1.88 2006/01/24 10:16:13 rgarciasuarez Exp $ =~ /(\d+\.\d+)/;
+(our $VERSION) = q$Id: args.pm,v 1.96 2006/02/13 11:36:12 rgarciasuarez Exp $ =~ /(\d+\.\d+)/;
 
 # The program that invokes us
 (my $tool = $0) =~ s!.*/!!;
@@ -70,8 +70,9 @@ my %options_spec = (
 	'auto-select' => \$::auto_select,
 	'auto-update' => sub { $::auto_update = $::auto_select = 1 },
 	'no-remove|no-uninstall' => \$::no_remove,
-	'no-install' => \$::no_install,
+	'no-install|noinstall' => \$::no_install,
 	keep => sub { $urpm->{options}{keep} = 1 },
+	'logfile=s' => \$::logfile,
 	'split-level=s' => sub { $urpm->{options}{'split-level'} = $_[1] },
 	'split-length=s' => sub { $urpm->{options}{'split-length'} = $_[1] },
 	'fuzzy!' => sub { $urpm->{options}{fuzzy} = $_[1] },
@@ -128,7 +129,9 @@ my %options_spec = (
 	'excludepath|exclude-path=s' => sub { $urpm->{options}{excludepath} = $_[1] },
 	'excludedocs|exclude-docs' => sub { $urpm->{options}{excludedocs} = 1 },
 	'ignoresize' => sub { $urpm->{options}{ignoresize} = 1 },
+	'ignorearch' => sub { $urpm->{options}{ignorearch} = 1 },
 	noscripts => sub { $urpm->{options}{noscripts} = 1 },
+	repackage => sub { $urpm->{options}{repackage} = 1 },
 	'more-choices' => sub { $urpm->{options}{morechoices} = 1 },
 	'expect-install!' => \$::expect_install,
 	'nolock' => \$::nolock,
@@ -147,6 +150,7 @@ my %options_spec = (
 	v => \$::verbose,
 	a => \$::matches,
 	noscripts => \$::noscripts,
+	repackage => \$::repackage,
     },
 
     #- see also below, autogenerated callbacks
@@ -213,6 +217,7 @@ my %options_spec = (
 	'list-url' => \$options{list_url},
 	'list-nodes' => \$options{list_nodes},
 	'list-aliases' => \$options{list_aliases},
+	'ignorearch' => \$options{ignorearch},
 	'dump-config' => \$options{dump_config},
 	'src|s' => \$options{src},
 	sources => \$options{sources},
@@ -310,6 +315,14 @@ my %options_spec = (
 	},
     },
 
+    'urpmi.recover' => {
+	'list=s' => \$::listdate,
+	'list-all' => sub { $::listdate = -1 },
+	checkpoint => \$::do_checkpoint,
+	'rollback=s' => \$::rollback,
+	noclean => \$::noclean,
+    },
+
 );
 
 # generate urpmf options callbacks
@@ -367,6 +380,10 @@ foreach my $k ("help|h", "wget", "curl", "proxy=s", "proxy-user=s", "c", "f", "z
     $options_spec{'urpmi.addmedia'}{$k} = $options_spec{'urpmi.update'}{$k};
 }
 
+foreach my $k ("help|h", "version") {
+    $options_spec{'urpmi.recover'}{$k} = $options_spec{urpmi}{$k};
+}
+
 sub parse_cmdline {
     my %args = @_;
     $urpm = $args{urpm};
